@@ -55,7 +55,6 @@ calculateAxisComponents <- function(x, ..., abbreviate = NULL, minlength = 4)
     ans <- formattedTicksAndLabels(x, ...)
 
     ## remove labels outside limits
-
     rng <- range(ans$num.limit)
     ok <- ans$at >= rng[1] & ans$at <= rng[2]
     ans$at <- ans$at[ok]
@@ -78,7 +77,8 @@ formattedTicksAndLabels <- function(x, ...)
 
 
 formattedTicksAndLabels.default <-
-    function (x, at = FALSE, used.at = NULL, num.limit = NULL, labels = FALSE, logsc = FALSE,
+    function (x, at = FALSE, used.at = NULL, num.limit = NULL,
+              labels = FALSE, logsc = FALSE,
               abbreviate = NULL, minlength = 4, format.posixt, ...)
 
     ## meant for when x is numeric
@@ -115,7 +115,7 @@ formattedTicksAndLabels.default <-
     list(at = at, labels = if (is.logical(labels))
          paste(logpaste, format(at, trim = TRUE), sep = "") else labels,
          check.overlap = check.overlap,
-         num.limit = if (length(x) == 2) x else range(x))
+         num.limit = if (length(x) == 2) as.numeric(x) else range(as.numeric(x)))
 }
 
 
@@ -127,7 +127,8 @@ formattedTicksAndLabels.default <-
 
 
 formattedTicksAndLabels.date <-
-    function (x, at = FALSE, used.at = NULL, num.limit = NULL, labels = FALSE, logsc = FALSE,
+    function (x, at = FALSE, used.at = NULL, num.limit = NULL,
+              labels = FALSE, logsc = FALSE,
               abbreviate = NULL, minlength = 4, format.posixt, ...)
 {
     ## handle log scales (not very meaningful, though)
@@ -188,7 +189,8 @@ formattedTicksAndLabels.character <-
 
 
 formattedTicksAndLabels.expression <-
-    function (x, at = FALSE, used.at = NULL, num.limit = NULL, labels = FALSE, logsc = FALSE,
+    function (x, at = FALSE, used.at = NULL, num.limit = NULL,
+              labels = FALSE, logsc = FALSE,
               abbreviate = NULL, minlength = 4, format.posixt, ...)
 {
     retain <- if (is.null(used.at) || any(is.na(used.at))) TRUE else used.at
@@ -206,7 +208,8 @@ formattedTicksAndLabels.expression <-
 
 
 formattedTicksAndLabels.POSIXct <-
-    function (x, at = FALSE, used.at = NULL, num.limit = NULL, labels = FALSE, logsc = FALSE, 
+    function (x, at = FALSE, used.at = NULL, num.limit = NULL,
+              labels = FALSE, logsc = FALSE, 
               abbreviate = NULL, minlength = 4,
               format.posixt = NULL, ...) 
 {
@@ -297,6 +300,78 @@ formattedTicksAndLabels.POSIXct <-
 
 
 
+
+
+
+
+
+
+
+## chron 'times' objects
+
+
+
+
+formattedTicksAndLabels.times <-
+    function (x, at = FALSE, used.at = NULL,
+              num.limit = NULL, labels = FALSE, logsc = FALSE, 
+              abbreviate = NULL, minlength = 4, simplify = TRUE, 
+              ...) 
+{
+    ## most arguments ignored for now
+
+    check.overlap <-
+        if (is.logical(at) && is.logical(labels)) TRUE
+        else FALSE
+
+    if (!inherits(x, "times")) 
+        x <- chron(x)
+    bad <- is.na(x) | abs(as.vector(x)) == Inf
+    ## rng <- extend.limits(range(as.numeric(x[!bad])))
+    rng <- range(as.numeric(x[!bad]))
+    tmp <- pretty(rng)
+    att <- attributes(x)
+    at <-
+        structure(tmp, # [tmp >= rng[1] & tmp <= rng[2]],
+                  format = att$format, 
+                  origin = att$origin,
+                  class = att$class)
+    if (inherits(at, "chron")) 
+        class(at) <- class(at)[-1]
+    if (is.logical(labels)) ## labels unspecified
+    {
+        if (!inherits(x, "dates"))
+        {
+            at[c(1, length(at))] <- range(x)
+            if (max(at) == 1) 
+                labels <- format(at - trunc(at), simplify = simplify)
+            else labels <- format(at, simplify = simplify)
+        }
+        else labels <- format(at, simplify = simplify)
+    }
+    ##invisible(list(n = n, at = at, labels = labels))
+
+    list(at = as.numeric(at), labels = labels, 
+         check.overlap = check.overlap,
+         num.limit = if (length(x) == 2) as.numeric(x) else rng)
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 panel.axis <-
     function(side = c("bottom", "left", "top", "right"),
              at = pretty(scale.range),
@@ -325,7 +400,7 @@ panel.axis <-
 {
     side <- match.arg(side)
     orientation <- if (outside) "outer" else "inner"
-    cvp <- current.viewport() ## grid should have accessors for xscale and yscale
+    cvp <- current.viewport() ## FIXME: grid should have accessors for xscale and yscale
     scale.range <-
         range(switch(side,
                      left = cvp$yscale,
@@ -345,31 +420,26 @@ panel.axis <-
 #    }
 
     if (is.null(at) || length(at) == 0) return()
-    keep.at <- TRUE
-    if (check.overlap) ## remove ticks close to limits
-    {
-        pad <- lattice.getOption("axis.padding")$numeric
-        scale.range <-
-            extend.limits(scale.range,
-                          prop = - 0.99 * pad / (1 + 2 * pad))
-
-        ## This 'just' includes the original range, assuming scales
-        ## were extended in the usual manner.  This is not exactly
-        ## what axis.padding was designed for, but it should be a good
-        ## enough default.  Of course, we can always add a new option
-        ## specially for this, but right now that seems overkill.
-
-        keep.at <- at >= scale.range[1] & at <= scale.range[2]
-    }
 
+    ## get labels from at if unspecified
     if (is.logical(labels))
         labels <-
             if (labels) format(at, trim = TRUE)
             else NULL
 
+    ## skip ticks outside axis limits
+    keep.at <- at >= scale.range[1] & at <= scale.range[2]
     at <- at[keep.at]
     labels <- labels[keep.at]
 
+    keep.labels <- TRUE
+    if (check.overlap) ## remove ticks close to limits
+    {
+        pad <- lattice.getOption("skip.boundary.labels")
+        scale.range <- extend.limits(scale.range, prop = -pad)
+        keep.labels <- at >= scale.range[1] & at <= scale.range[2]
+    }
+
     nal <- length(at) / 2 + 0.5
     all.id <- seq(along = at)
     lower.id <- all.id <= nal
@@ -379,7 +449,7 @@ panel.axis <-
         {
             if (which.half == "lower") lower.id else upper.id
         }
-        else all.id
+        else rep(TRUE, length(all.id))
 
     gp.line <- gpar(col = line.col, alpha = line.alpha,
                     lty = line.lty, lwd = line.lwd)
@@ -456,32 +526,32 @@ panel.axis <-
         }
         switch(side,
                bottom =
-               grid.text(label = labels[axid],
-                         x = unit(at[axid], "native"),
+               grid.text(label = labels[axid & keep.labels],
+                         x = unit(at[axid & keep.labels], "native"),
                          y = orient.factor * lab.unit,
                          rot = rot[1],
                          check.overlap = check.overlap,
                          just = just,
                          gp = gp.text),
                top =
-               grid.text(label = labels[axid],
-                         x = unit(at[axid], "native"),
+               grid.text(label = labels[axid & keep.labels],
+                         x = unit(at[axid & keep.labels], "native"),
                          y = unit(1, "npc") - orient.factor * lab.unit,
                          rot = rot[1],
                          check.overlap = check.overlap,
                          just = just,
                          gp = gp.text),
                left =
-               grid.text(label = labels[axid],
-                         y = unit(at[axid], "native"),
+               grid.text(label = labels[axid & keep.labels],
+                         y = unit(at[axid & keep.labels], "native"),
                          x = orient.factor * lab.unit,
                          rot = rot[2],
                          check.overlap = check.overlap,
                          just = just,
                          gp = gp.text),
                right =
-               grid.text(label = labels[axid],
-                         y = unit(at[axid], "native"),
+               grid.text(label = labels[axid & keep.labels],
+                         y = unit(at[axid & keep.labels], "native"),
                          x = unit(1, "npc") - orient.factor * lab.unit,
                          rot = rot[2],
                          check.overlap = check.overlap,
